diff src/protocols/msn/httpconn.h @ 13914:3ae8a3935406

[gaim-migrate @ 16414] First stab at trying to fix the MSN http connect method. It still doesn't work, and I'm not sure why, but it gets a lot farther in the signon process now. For those unfamiliar with the issue, the MSN http connect method stopped working after all the non-blocking I/O changes. The http connect method is apparently used by lots of people behind silly firewalls and stuff, and therefore we really shouldn't release Gaim 2.0.0 without it working, because people will complain. The two main problems were 1. The outgoing message queue was removed in favor of buffering all data to one large buffer. This sounds good in theory... but apparently each message sent to and from the server has a "SessionID" in the HTTP header. Every message we send should use the same SessionID as the last packet we received from the server. So basically you can't put two messages into the outgoing buffer at the same time because you don't have the correct SessionID to use for the second message. You have to wait until you get the reply from the server. 2. There were some strange buffer problems with using the wrong variable when trying to combine the header+body into one buffer before sending the message. I also fixed a small memleak or two, added some comments, and tried to clean up the code a little. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Mon, 03 Jul 2006 20:39:04 +0000
parents 8754a0fe2297
children 614c56622453
line wrap: on
line diff
--- a/src/protocols/msn/httpconn.h	Mon Jul 03 18:28:13 2006 +0000
+++ b/src/protocols/msn/httpconn.h	Mon Jul 03 20:39:04 2006 +0000
@@ -44,13 +44,13 @@
 
 	gboolean waiting_response; /**< The flag that states if we are waiting
 								 a response from the server. */
-	gboolean dirty;            /**< The flag that states if we should poll. */
 	gboolean connected;        /**< The flag that states if the connection is on. */
 	gboolean virgin;           /**< The flag that states if this connection
 								 should specify the host (not gateway) to
 								 connect to. */
 
 	char *host; /**< The HTTP gateway host. */
+	GList *queue; /**< The queue of data chunks to write. */
 
 	int fd; /**< The connection's file descriptor. */
 	guint inpa; /**< The connection's input handler. */
@@ -83,11 +83,11 @@
  *
  * @param servconn    The server connection.
  * @param data        The data to write.
  * @param size        The size of the data to write.
  *
  * @return The number of bytes written.
  */
-ssize_t msn_httpconn_write(MsnHttpConn *httpconn, const char *data, size_t size);
+ssize_t msn_httpconn_write(MsnHttpConn *httpconn, const char *data, size_t data_len);
 
 /**
  * Connects the HTTP connection object to a host.
@@ -83,11 +83,11 @@
  * @param servconn    The server connection.
  * @param data        The data to write.
- * @param size        The size of the data to write.
+ * @param data_len    The size of the data to write.
  *
  * @return The number of bytes written.